@@ -46,10 +46,11 @@ class ApprcWatcherTest(unittest.TestCase):
         plugin.add_envs(name="name", envs={"foo": "bar"})
         env = copy.deepcopy(os.environ)
         env["foo"] = "bar"
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
 
     def test_add_envs_may_override_os_environ(self):
@@ -64,10 +65,11 @@ class ApprcWatcherTest(unittest.TestCase):
         env = copy.deepcopy(os.environ)
         env["SOMETHING_UNKNOWN"] = "456"
         env["foo"] = "bar"
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
 
     def test_add_envs_dont_call_set_when_variables_dont_change(self):
@@ -90,10 +92,11 @@ class ApprcWatcherTest(unittest.TestCase):
         plugin.add_envs(name="name", envs={"foo": "bar"})
         env = copy.deepcopy(os.environ)
         env["foo"] = "bar"
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
 
     def test_add_env_ignores_PYTHONPATH_from_os_environ(self):
@@ -107,10 +110,11 @@ class ApprcWatcherTest(unittest.TestCase):
         env = copy.deepcopy(os.environ)
         env["foo"] = "bar"
         del env["PYTHONPATH"]
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
 
     def test_add_env_doesnt_ignore_PYTHONPATH_from_apprc(self):
@@ -123,10 +127,11 @@ class ApprcWatcherTest(unittest.TestCase):
         env = copy.deepcopy(os.environ)
         env["foo"] = "bar"
         env["PYTHONPATH"] = "/usr/lib/python"
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
 
     def test_reload_env_add_envs(self):
@@ -149,14 +154,15 @@ class ApprcWatcherTest(unittest.TestCase):
             {"name": "cmd", "options": {"env": env}},
             {"name": "name", "options": {"env": env}},
         ]
-        expected = [{"cmd": "stop", "args": {"name": "cmd"}},
+        expected = [{"cmd": "stop", "args": {"name": "cmd", "waiting": True}},
                     {"cmd": "set", "args": {"name": "cmd",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "cmd"}},
-                    {"cmd": "stop", "args": {"name": "name"}},
+                    {"cmd": "start", "args": {"name": "cmd", "waiting": True}},
+                    {"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, sorted(kw, key=lambda x: x["args"]["name"]))
 
     def test_reload_env_skips_plugins(self):
@@ -176,8 +182,9 @@ class ApprcWatcherTest(unittest.TestCase):
             "PORT": "8888"
         }
         env.update(os.environ)
-        expected = [{"cmd": "stop", "args": {"name": "name"}},
+        expected = [{"cmd": "stop", "args": {"name": "name", "waiting": True}},
                     {"cmd": "set", "args": {"name": "name",
                                             "options": {"env": env}}},
-                    {"cmd": "start", "args": {"name": "name"}}]
+                    {"cmd": "start", "args": {"name": "name",
+                                              "waiting": True}}]
         self.assertEqual(expected, kw)
